import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.Application;
import com.hrsk.cloud.eg.domain.api.ApiGateway;
import com.hrsk.cloud.eg.domain.api.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.resolver.vo.SpelValueObjectResolver;
import com.hrsk.cloud.eg.dto.data.CheckIntoParamDto;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserInBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.business.GenerateCheckIntoHttpApiConfigService;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiEndpointService;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.expression.ExpressionParser;
import org.springframework.expression.spel.standard.SpelExpressionParser;
import org.springframework.expression.spel.support.StandardEvaluationContext;
import org.springframework.test.context.junit4.SpringRunner;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author zhangyy
 * @version 1.0
 * @description: Test
 * @date 2024/8/28 17:03
 */
@RunWith(SpringRunner.class)
@SpringBootTest(classes = Application.class)
public class StartTest {

    @Resource
    private GenerateCheckIntoHttpApiConfigService generateCHeckIntoHttpApiConfigService;

    @Resource
    private ProductBusinessApiInfoService productBusinessApiInfoService;

    @Resource
    private EgApiEndpointService egApiEndpointService;

    @Resource
    private ApiGateway apiGateway;
    @Test
  public void createHuiRonApiTest(){
        List<ProductBusinessApiInfoDo> productBusinessApiInfoDos = productBusinessApiInfoService.selectByJointCodeForList("9");
        String jsonString = JSONObject.toJSONString(productBusinessApiInfoDos.get(0));
        generateCHeckIntoHttpApiConfigService.generateHuiRonHuiRonApiConfig(jsonString);
  }

    @Test
    public void createOpenApiRsaTest(){
        List<ProductBusinessApiInfoDo> productBusinessApiInfoDos = productBusinessApiInfoService.selectByJointCodeForList("1");
        String jsonString = JSONObject.toJSONString(productBusinessApiInfoDos.get(0));
        generateCHeckIntoHttpApiConfigService.generateOpenApiRSAConfig(jsonString);
    }


    @Test
    public void createQinYuApiTest(){
        List<ProductBusinessApiInfoDo> productBusinessApiInfoDos = productBusinessApiInfoService.selectByJointCodeForList("4");
//        String jsonString = JSONObject.toJSONString(productBusinessApiInfoDos.get(0).getThreeSystemConfig());
        generateCHeckIntoHttpApiConfigService.generateQinYuConfig(productBusinessApiInfoDos.get(0).getThreeSystemConfig());
    }


    @Test
    public void apiHuiRonTest(){
      Long apiId= 441293753667392L;
        UserInBaseInfoDto user =new UserInBaseInfoDto();
        user.setPhoneMd5("b5500dfab55f42b340d31326561e16cb");
        PlanDto  plan =new PlanDto();
        plan.setApiId(apiId);
        plan.setBid("aff1c7b30d8b240826030235business");
        CheckIntoParamDto checkin =new CheckIntoParamDto();
        checkin.setPlan(plan);
        checkin.setUser(user);
        apiGateway.checkIntoRequest(checkin);
    }


    @Test
    public void openApiRsaTest(){
        Long apiId= 441312253769280L;
        UserInBaseInfoDto user =new UserInBaseInfoDto();
        user.setPhoneMd5("b5500dfab55f42b340d31326561e16cb");
        user.setCompanyCity("重庆");
        PlanDto  plan =new PlanDto();
        plan.setApiId(apiId);
        plan.setBid("aff1c7b30d8b240826030235business");
        CheckIntoParamDto checkin =new CheckIntoParamDto();
        checkin.setPlan(plan);
        checkin.setUser(user);
        apiGateway.checkIntoRequest(checkin);
    }

    /** 
     * @description: 庆鱼暂时不支持解析 ！！！
     * @param:  
     * @return:  
     * @author zhangyy
     * @date: 2024/9/5 11:03
     */ 
    @Test
    public void qinYuApiRsaTest(){
        Long apiId= 441333216126016L;
        UserInBaseInfoDto user =new UserInBaseInfoDto();
        user.setPhoneMd5("b5500dfab55f42b340d31326561e16cb");
        user.setCompanyCity("重庆");
        PlanDto  plan =new PlanDto();
        plan.setApiId(apiId);
        plan.setBid("aff1c7b30d8b240826030235business");
        CheckIntoParamDto checkin =new CheckIntoParamDto();
        checkin.setPlan(plan);
        checkin.setUser(user);
        apiGateway.checkIntoRequest(checkin);
    }


    @Test
    public void spel(){
        Map<String,Object> map =new HashMap<>();
        map.put("key","1");
        Map<String,Object> map2 =new HashMap<>();
        List<String> list =new ArrayList<>();
        list.add("1");
        list.add("2");
        map2.put("key","3");
        map.put("1",list);
         String spel = "#root['1'][0]";
        ExpressionParser parser = new SpelExpressionParser();
        StandardEvaluationContext context = new StandardEvaluationContext(map);
        // 这里很关键，如果没有配置MapAccessor，那么只能用['c']['a']这种解析方式
        System.out.println(parser.parseExpression(spel).getValue(context));


    }


}
